@@ -8,13 +8,20 @@ import json
 import enum
 import copy
 
-__version__ = '1.0.0'
+__version__ = '1.1.0'
 
 
 class ProfileError(Exception):
     """ Failed to parse a profile file """
 
 
+class TemplateVarError(Exception):
+    """ Undefined template variable """
+    def __init__(self, name):
+        super().__init__(f'Undefined variable {name}')
+        self.name = name
+
+
 class Logger:
     """ Simple console logger with ANSI color support """
 
@@ -184,10 +191,14 @@ class SrcDstAction(ProfileEntry):
         if not isinstance(json_action, dict):
             raise TypeError(f'"{type}" element must be an object')
 
-        for field in ['src', 'dst']:
-            if field not in json_action or not isinstance(json_action[field], str):
-                raise TypeError(f'"{type}" must have "{field}" field of type string')
-            setattr(self, field, json_action[field])
+        if 'src' not in json_action or not isinstance(json_action['src'], str):
+            raise TypeError(f'"{type}" must have "src" field of type string')
+
+        if 'dst' not in json_action or not isinstance(json_action['dst'], str):
+            raise TypeError(f'"{type}" must have "dst" field of type string')
+
+        self.src = json_action['src']
+        self.dst = json_action['dst']
 
     def __eq__(self, other):
         return (self.src, self.dst) == (other.src, other.dst)
@@ -249,7 +260,11 @@ class TemplateAction(SrcDstAction):
 
         with open(src, 'r') as src_file:
             tpl = string.Template(src_file.read())
-            rendered = tpl.substitute(vars)
+
+            try:
+                rendered = tpl.substitute(vars)
+            except KeyError as e:
+                raise TemplateVarError(str(e))
 
             with open(dst, 'r+' if dst_exists else 'w') as dst_file:
                 if dst_exists:
@@ -278,7 +293,7 @@ class Profile:
 
     def __init__(self, filename):
         self.name = filename.with_suffix('').name
-        self.parents = None
+        self.parents = []
 
         try:
             with open(filename, 'r') as f:
@@ -536,7 +551,7 @@ def main():
             dotref = Dotref(log, args)
             dotref.do(args.command)
         except Exception as e:
-            log.err(str(e))
+            log.err(f'\nError: {str(e)}')
             if args.verbose > 0:
                 raise
             else:
